@@ -1,10 +1,12 @@
+# The contents of this file is free and unencumbered software released into the
+# public domain. For more information, please refer to <http://unlicense.org/>
+
 from anilistWrapPY.Media.types import AniListMedia
 from anilistWrapPY.Media.graphql import media_query
 import httpx
 
-baseUrl = "https://graphql.anilist.co"
 
-def GetMedia(search: str) -> AniListMedia:
+def GetMedia(search: str, baseUrl: str) -> AniListMedia:
     variables = {"search": search}
     r = (httpx.post(baseUrl, json={"query": media_query, "variables": variables})).json()
     return AniListMedia(**r)
\ No newline at end of file
